@@ -1,6 +1,6 @@
 # glmnet.R: plotmo functions for glmnet objects
 
-plotmo.prolog.glmnet <- function(object, object.name, ...) # invoked when plotmo starts
+plotmo.prolog.glmnet <- function(object, object.name, trace, ...) # invoked when plotmo starts
 {
     # stash (possibly user specified) s for use by plot.glmnetx and predict.glmnet
     s <- dot("predict.s", ...)
@@ -41,8 +41,9 @@ plotmo.singles.glmnet <- function(object, x, nresponse, trace, all1)
     nsingles <- sum(abs(beta) > 1e-8) # drop zero coefs
     order[seq_len(nsingles)]
 }
-# Note: you have to manually assign x and y to the cv.glmnet object before
-# calling plotmo, because cv.glmnet objects do not have a call field.
+# Note: you have to manually assign x and y to the cv.glmnet object
+# before calling plotmo, because cv.glmnet objects do not have a call
+# field (checked in glmnet version 2.0.2).
 
 plotmo.predict.cv.glmnet <- function(object, newdata, type, ..., TRACE)
 {
